@@ -48,10 +48,12 @@ def add_alarm_status(
         print(new_alarm_status)
     """
     alarm_status_input = AddAlarmStatusInput(name=name)
-    if (name is None):
+    if (name ==""):
         print ("you cant leave the name parameter empty and must be a text")
     if (name!=str):
         print ("you cant leave the name parameter empty and must be a text")
+    if name is None:
+        print ("you cant leave the name parameter empty and must be a text")
     else:
         result = addAlarmStatus.execute(client, input=alarm_status_input)
         return alarmStatus(name=result.name, id=result.id)
